@@ -432,8 +432,23 @@ def auto_namespaced_kat_cls(res_name_or_kind: str) -> Optional[Type[KatRes]]:
 def from_dict(dict_repr: Dict):
   api = ApiClient()
   mocked_kube_http_resp = FakeKubeResponse(dict_repr)
-  kind = dict_repr['kind']
-  return api.deserialize(mocked_kube_http_resp, f"V1{kind}")
+  kind = dict_repr.get('kind')
+  class_guesses = [
+    f"V1{kind}",
+    f"V1alpha1{kind}",
+    f"V1beta1{kind}",
+    f"V2alpha1{kind}",
+    f"V2beta1{kind}",
+    "V1Pod"
+  ]
+
+  for guess in class_guesses:
+    try:
+      getattr(kubernetes.client.models, guess)
+      print(f"win for {guess}")
+      return api.deserialize(mocked_kube_http_resp, guess)
+    except:
+      pass
 
 
 class FakeKubeResponse:
